package dev.adriankuta.flights.ui.home

import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import dagger.hilt.android.lifecycle.HiltViewModel
import dev.adriankuta.flights.domain.search.ObserveAirportsUseCase
import dev.adriankuta.flights.domain.types.AirportInfo
import kotlinx.coroutines.delay
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.SharingStarted
import kotlinx.coroutines.flow.flatMapLatest
import kotlinx.coroutines.flow.flow
import kotlinx.coroutines.flow.map
import kotlinx.coroutines.flow.stateIn
import javax.inject.Inject
import kotlin.time.Duration.Companion.seconds

@HiltViewModel
class HomeScreenViewModel @Inject constructor(
    private val observeAirportsUseCase: ObserveAirportsUseCase
) : ViewModel() {

    internal val uiState = homeUiState(
        useCase = observeAirportsUseCase
    )
        .stateIn(
            scope = viewModelScope,
            started = SharingStarted.WhileSubscribed(5_000),
            initialValue = HomeUiState(),
        )
}

private fun homeUiState(
    useCase: ObserveAirportsUseCase
): Flow<HomeUiState> {

    return flow {
        delay(15.seconds)
        emit("")
    }.flatMapLatest { useCase() }.map {
        HomeUiState(it.orEmpty())
    }
}

internal data class HomeUiState(
    val airports: List<AirportInfo> = emptyList()
)
